import { Body, Controller, Put, Request, UseGuards } from '@nestjs/common';
import { AuthGuard } from '@nestjs/passport';
import { ApiBearerAuth, ApiBody, ApiOperation, ApiTags } from '@nestjs/swagger';
import { InstitucionUsuarioService } from './institucion-usuario.service';
import { ValidarUsuarioService } from '../validar-usuario/validar-usuario.service';
import { Operador } from '../operador/entity/operador.entity';
import { UpdateInstitucionUsuarioInputDto } from './dto/input/update.dto';

@Controller('institucion-usuario')
@ApiTags('institucion-usuario')
export class InstitucionUsuarioController {
  constructor(
    private institucionUsuarioService: InstitucionUsuarioService,
    private validarUsuarioService: ValidarUsuarioService,
  ) {}

  @Put()
  @UseGuards(AuthGuard('jwt'))
  @ApiOperation({
    description: 'Enpoint que actualiza la información de un usuario.',
  })
  @ApiBearerAuth('jwt')
  @ApiBody({
    description: 'Todas las variables son obligatorias.',
    examples: {
      ejemplo: {
        value: {
          activo: true,
          id_institucion_usuario: 1,
        },
      },
    },
  })
  update(@Request() req, @Body() body: UpdateInstitucionUsuarioInputDto) {
    const admin: Operador = req.user.operador;

    this.validarUsuarioService.validarAdminOperador(admin);
    return this.institucionUsuarioService.update(body);
  }
}
